#line 2 "udunits2/utscanner.c"

#line 4 "udunits2/utscanner.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer harp_ut_create_buffer
#define yy_delete_buffer harp_ut_delete_buffer
#define yy_scan_buffer harp_ut_scan_buffer
#define yy_scan_string harp_ut_scan_string
#define yy_scan_bytes harp_ut_scan_bytes
#define yy_init_buffer harp_ut_init_buffer
#define yy_flush_buffer harp_ut_flush_buffer
#define yy_load_buffer_state harp_ut_load_buffer_state
#define yy_switch_to_buffer harp_ut_switch_to_buffer
#define yypush_buffer_state harp_utpush_buffer_state
#define yypop_buffer_state harp_utpop_buffer_state
#define yyensure_buffer_stack harp_utensure_buffer_stack
#define yy_flex_debug harp_ut_flex_debug
#define yyin harp_utin
#define yyleng harp_utleng
#define yylex harp_utlex
#define yylineno harp_utlineno
#define yyout harp_utout
#define yyrestart harp_utrestart
#define yytext harp_uttext
#define yywrap harp_utwrap
#define yyalloc harp_utalloc
#define yyrealloc harp_utrealloc
#define yyfree harp_utfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define harp_ut_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer harp_ut_create_buffer
#endif

#ifdef yy_delete_buffer
#define harp_ut_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer harp_ut_delete_buffer
#endif

#ifdef yy_scan_buffer
#define harp_ut_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer harp_ut_scan_buffer
#endif

#ifdef yy_scan_string
#define harp_ut_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string harp_ut_scan_string
#endif

#ifdef yy_scan_bytes
#define harp_ut_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes harp_ut_scan_bytes
#endif

#ifdef yy_init_buffer
#define harp_ut_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer harp_ut_init_buffer
#endif

#ifdef yy_flush_buffer
#define harp_ut_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer harp_ut_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define harp_ut_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state harp_ut_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define harp_ut_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer harp_ut_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define harp_utpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state harp_utpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define harp_utpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state harp_utpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define harp_utensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack harp_utensure_buffer_stack
#endif

#ifdef yylex
#define harp_utlex_ALREADY_DEFINED
#else
#define yylex harp_utlex
#endif

#ifdef yyrestart
#define harp_utrestart_ALREADY_DEFINED
#else
#define yyrestart harp_utrestart
#endif

#ifdef yylex_init
#define harp_utlex_init_ALREADY_DEFINED
#else
#define yylex_init harp_utlex_init
#endif

#ifdef yylex_init_extra
#define harp_utlex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra harp_utlex_init_extra
#endif

#ifdef yylex_destroy
#define harp_utlex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy harp_utlex_destroy
#endif

#ifdef yyget_debug
#define harp_utget_debug_ALREADY_DEFINED
#else
#define yyget_debug harp_utget_debug
#endif

#ifdef yyset_debug
#define harp_utset_debug_ALREADY_DEFINED
#else
#define yyset_debug harp_utset_debug
#endif

#ifdef yyget_extra
#define harp_utget_extra_ALREADY_DEFINED
#else
#define yyget_extra harp_utget_extra
#endif

#ifdef yyset_extra
#define harp_utset_extra_ALREADY_DEFINED
#else
#define yyset_extra harp_utset_extra
#endif

#ifdef yyget_in
#define harp_utget_in_ALREADY_DEFINED
#else
#define yyget_in harp_utget_in
#endif

#ifdef yyset_in
#define harp_utset_in_ALREADY_DEFINED
#else
#define yyset_in harp_utset_in
#endif

#ifdef yyget_out
#define harp_utget_out_ALREADY_DEFINED
#else
#define yyget_out harp_utget_out
#endif

#ifdef yyset_out
#define harp_utset_out_ALREADY_DEFINED
#else
#define yyset_out harp_utset_out
#endif

#ifdef yyget_leng
#define harp_utget_leng_ALREADY_DEFINED
#else
#define yyget_leng harp_utget_leng
#endif

#ifdef yyget_text
#define harp_utget_text_ALREADY_DEFINED
#else
#define yyget_text harp_utget_text
#endif

#ifdef yyget_lineno
#define harp_utget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno harp_utget_lineno
#endif

#ifdef yyset_lineno
#define harp_utset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno harp_utset_lineno
#endif

#ifdef yywrap
#define harp_utwrap_ALREADY_DEFINED
#else
#define yywrap harp_utwrap
#endif

#ifdef yyalloc
#define harp_utalloc_ALREADY_DEFINED
#else
#define yyalloc harp_utalloc
#endif

#ifdef yyrealloc
#define harp_utrealloc_ALREADY_DEFINED
#else
#define yyrealloc harp_utrealloc
#endif

#ifdef yyfree
#define harp_utfree_ALREADY_DEFINED
#else
#define yyfree harp_utfree
#endif

#ifdef yytext
#define harp_uttext_ALREADY_DEFINED
#else
#define yytext harp_uttext
#endif

#ifdef yyleng
#define harp_utleng_ALREADY_DEFINED
#else
#define yyleng harp_utleng
#endif

#ifdef yyin
#define harp_utin_ALREADY_DEFINED
#else
#define yyin harp_utin
#endif

#ifdef yyout
#define harp_utout_ALREADY_DEFINED
#else
#define yyout harp_utout
#endif

#ifdef yy_flex_debug
#define harp_ut_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug harp_ut_flex_debug
#endif

#ifdef yylineno
#define harp_utlineno_ALREADY_DEFINED
#else
#define yylineno harp_utlineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define harp_utwrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 20
#define YY_END_OF_BUFFER 21
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[271] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       21,   19,    3,   20,   18,    3,   19,    3,    3,    2,
       14,    1,   18,   18,   18,   18,   18,   18,   19,   18,
       19,   19,   19,   19,   19,   19,    3,    3,   14,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,    7,
       19,    9,    9,    9,   19,   12,   19,    3,    2,    1,
        0,    0,    0,    0,    0,    0,    0,   14,   13,    2,
       13,    0,    1,    0,   18,   18,    0,    0,    0,    0,
       18,   18,   18,   18,    0,    4,   18,   18,   18,   18,
       18,    5,    3,    0,    0,   14,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    7,    7,    0,    7,
        7,    7,    7,    9,    9,    9,    9,    9,    0,    9,
        9,   11,   12,    0,    0,   13,    0,   13,   18,    0,
       18,    2,    1,   18,    0,    0,    0,    0,    0,    0,
        0,    0,    5,   18,    0,    0,    0,    5,    0,    0,
        6,    6,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    9,    9,    9,    8,    8,    9,    9,
        9,    9,   10,    0,   13,   18,   18,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    6,    0,
        6,    7,    7,    7,    7,    7,    7,    7,    7,    7,

        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    9,    9,    8,    0,   17,   15,   16,    0,    0,
        6,    6,    6,   14,    7,    7,    7,    7,    7,    7,
        7,   14,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    9,    8,    8,    8,   17,    0,   15,
        0,   16,    0,    5,    7,    7,    7,   14,    7,    7,
        7,    7,    7,    7,    8,   17,   15,   16,    8,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    1,    1,    5,    1,    6,    7,
        1,    8,    9,    1,   10,   11,   12,   13,   14,   15,
       16,   17,   17,   18,   19,   19,   19,   20,    1,    1,
        1,    1,    1,   21,   22,   23,   24,   23,   25,   26,
       23,   23,   27,   23,   23,   23,   28,   29,   30,   31,
       23,   32,   33,   34,   23,   23,   23,   23,   23,   23,
        1,    1,    1,   35,   23,    1,   22,   36,   24,   23,

       25,   26,   37,   23,   27,   23,   23,   38,   28,   39,
       40,   31,   23,   32,   33,   41,   23,   23,   23,   23,
       23,   23,    1,    1,    1,    1,    1,   42,   43,   42,
       42,   42,   42,   42,   42,   42,   42,   42,   42,   42,
       42,   42,   42,   42,   42,   42,   42,   42,   42,   42,
       44,   45,   45,   45,   45,   45,   45,   45,   45,   46,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   45,   47,   45,   45,   48,   45,   49,   50,   51,
       52,   51,   53,   54,   55,   56,   57,   58,   58,   58,
       58,    1,    1,   59,   60,    1,    1,    1,    1,   61,

       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   62,   62,   63,   62,   62,   62,   62,
       62,   62,   62,   62,   62,   62,   62,   62,   62,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[64] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    2,    3,    2,    2,    2,    2,    2,    2,
        2,    2,    3,    2,    2,    2,    2,    2,    1,    1,
        1,    1,    1
    } ;

static const flex_int16_t yy_base[276] =
    {   0,
        0,    0,   62,  124,  185,  221,  257,  293,  330,    0,
     1072, 1261,   80, 1261, 1261, 1055,  150,  159,  101, 1058,
      194, 1057,  381, 1032,   59,   41,   43,   60,  232,  145,
      231,    0,   45,    0, 1014,  239,  274, 1261,  300, 1030,
     1023, 1029, 1016, 1003,   68,   98,  984,  309,  353,  443,
      360,  414,  465,  473,  367,  481,   76,  500, 1024, 1023,
      992,  974,  972,  954,  940,  500,  433,  523,  536,  927,
      549,  562,  925,  881,  876,  180,  145,    0,   46,    0,
      203,   77,  875,  189,  569,  576,  218,  327,  328,  123,
      860,   95, 1261,  136,  554,  600,  145,  186,  851,  839,

      188,  261,  262,  292,  816,  572,    0,  839,  617,  635,
      668,  116, 1261,  690,  698,  838,  717,  725,  625,  744,
      751,  648,  758,  658,  770,  777,  707,  790,  236,  306,
      272,  295,  331,  334,  385,  423,  462,  433,  464,  471,
      456,  777,  411,  413,  792,  700,  677,  242,  445,  680,
      808,  525,  841,  874,  510,    0,  907,  515,  323,    0,
      530,    0,    0,  813,  929,  947,  937,  727,  957,  967,
      545,  353,  820,  831,  854,  722,  365,  656,  655,  657,
      622,  749,  548,  826,  848,  517,  525,  495,  505,  897,
     1261,  985, 1018,  642,    0, 1051,  784,  388,    0,  798,

        0,    0,    0,    0,    0,  410,    0,    0,    0,    0,
        0,  975, 1073,  461,  998,  780,  799,  862,  994,  919,
     1080, 1037,  188, 1090, 1114,  848,  742, 1147,  891,  556,
        0, 1127,    0,    0,    0,    0,    0,  608,    0,  995,
        0,    0,    0, 1169, 1178,  917,  814,  436,  434,  424,
      386,  302,  283,  981,    0, 1196,  677, 1209, 1008,    0,
        0,  736,  269,    0, 1227,  263,  150,  142, 1234, 1261,
     1253,  108, 1255,   94, 1257
    } ;

static const flex_int16_t yy_def[276] =
    {   0,
      270,    1,  271,  271,  271,  271,  271,  271,    1,    9,
      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,   23,   23,   23,   23,   23,  270,   23,
      270,  272,  272,  273,  273,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,   23,   23,   23,  270,  274,  274,  275,
       23,   23,   23,   23,  270,  270,   23,   23,   23,   23,
       23,  270,  270,  272,  270,  270,  270,  270,  270,  270,

      270,  270,  270,  270,  270,  270,   50,  270,  270,  270,
      270,  111,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  270,  270,  270,  270,   23,  274,
       23,   23,   23,   23,  270,  270,  270,  270,  270,  270,
      270,  270,   23,   23,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  154,  155,  270,  157,  155,  155,
      155,  157,  158,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  270,   23,   23,  270,  270,  270,
      270,  270,  270,  270,  270,  275,  270,  270,  270,  270,
      270,  270,  270,  193,  194,  270,  196,  194,  194,  194,

      196,  197,  194,  196,  197,  194,  194,  200,  196,  197,
      193,  270,  270,  270,  270,  270,  270,  270,  274,  270,
      270,  270,  270,  270,  270,  225,  194,  270,  228,  226,
      226,  270,  228,  229,  227,  228,  229,  226,  226,  200,
      228,  229,  225,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,   23,  226,  270,  256,  270,  226,  226,
      256,  256,  259,  259,  270,  270,  270,  270,  270,    0,
      270,  270,  270,  270,  270
    } ;

static const flex_int16_t yy_nxt[1325] =
    {   0,
       12,   13,   14,   15,   15,   15,   12,   16,   17,   18,
       19,   20,   21,   21,   21,   21,   21,   21,   21,   12,
       22,   23,   24,   24,   24,   25,   24,   24,   24,   24,
       26,   27,   28,   24,   29,   24,   24,   30,   24,   24,
       24,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   31,   32,
       33,   34,   35,   13,   14,   82,   75,   83,   75,   16,
       36,   37,   38,   20,   39,   39,   39,   39,   39,   39,
       39,   58,   22,   40,   75,   75,   84,   41,   91,   75,
       81,   59,   42,   43,   44,   75,   29,   91,   75,   45,

       60,   61,   75,  102,  103,   62,  104,  105,  132,   91,
       63,   64,   65,   69,   69,   69,   69,   69,   69,   69,
       46,   91,   91,   91,   47,   13,   14,   91,  161,  162,
      163,   16,   36,   37,   38,   20,   39,   39,   39,   39,
       39,   39,   39,  252,   22,   40,   92,   92,   75,   41,
       93,  250,   92,  141,   42,   43,   44,  142,   29,   88,
       67,   45,   68,   68,   68,   68,   68,   68,   68,   67,
       75,   68,   68,   68,   68,   68,   68,   68,  145,   91,
       87,   88,   46,   89,   90,  145,   47,   14,   91,  189,
       75,   75,   75,   48,   48,   49,   75,   50,   50,   50,

       50,   50,   50,   50,   71,   75,   68,   68,   68,   68,
       68,   68,   68,  129,   75,  146,  147,  134,   72,  135,
      129,  191,   45,   14,  136,  146,  147,  134,   75,   48,
       48,   49,  131,   50,   50,   50,   50,   50,   50,   50,
       85,   85,  131,   75,   86,   86,   86,   86,   86,   86,
       86,   96,   96,   96,   96,   96,   96,   96,   45,   14,
      176,   75,  135,  137,  248,   51,   51,  136,  138,   52,
       52,   53,   54,   54,   54,   54,   91,   91,   91,   92,
       92,   68,   91,   93,  268,   92,   96,   96,   96,   96,
       96,   96,   96,  139,   45,   14,   70,   75,  140,  133,

      141,   51,   51,  252,  142,   52,   52,   53,   54,   54,
       54,   54,   96,   96,   96,   96,   96,   96,   96,   67,
       75,  107,  107,  107,  107,  107,  107,  107,  137,  139,
       45,   12,   73,  138,  140,  208,  209,   12,   55,   55,
       12,   12,   56,   56,   56,   56,   56,   56,   56,   75,
       12,   24,   75,   75,  116,   24,   75,  177,   75,   75,
       24,   24,   24,  212,   12,   69,   69,   69,   69,   69,
       69,   69,  114,  114,  115,  115,  115,  115,  115,  122,
      122,  122,  122,  122,  122,  122,  135,  267,   57,  133,
       75,  136,   34,   74,   74,   74,   74,   74,   74,   74,

      240,  241,   75,   75,   75,   75,   76,   75,   75,   75,
       75,   75,   75,   75,   75,  116,   75,   75,   75,   75,
       75,   75,  240,  241,  178,  250,  117,  117,  117,  117,
      117,  118,  118,  119,  180,  266,   75,  248,   75,   77,
       78,   79,   80,   80,  108,   69,   69,   69,   69,   69,
       69,   69,  109,   71,  179,  110,  111,  112,  112,  112,
      112,  112,  214,  137,  181,  139,  116,   72,  138,  185,
      140,  185,  182,  186,  116,  186,  113,  117,  117,  117,
      117,  120,  121,  121,  119,  120,  120,  120,  120,  120,
      121,  121,  119,  123,  123,  123,  123,  123,  123,  123,

      124,   58,  183,  141,   92,   92,  189,  142,   85,   85,
       92,   59,   86,   86,   86,   86,   86,   86,   86,   60,
       60,   61,  200,  201,  202,   62,  189,  208,  209,  210,
       63,   64,   65,   71,  190,   68,   68,   68,   68,   68,
       68,   68,  192,  211,  199,  199,  116,   72,   69,   69,
       69,   69,   69,   69,   69,  212,   60,  172,  191,  219,
      125,  126,  126,  126,  126,  126,  126,  126,  263,  264,
      127,  127,  218,  125,  128,  128,  128,  128,  128,  128,
      128,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   91,   91,   91,   91,   91,

       91,  143,   91,   91,  143,  143,  143,  143,  143,  144,
      144,   91,   96,   96,   96,   96,   96,   96,   96,  148,
      263,  264,  148,  148,  148,  148,  148,  149,  149,  150,
      151,  152,  152,  152,  152,  152,  108,  167,  167,  167,
      167,  167,  168,  168,  109,   71,  217,  153,  154,  155,
      155,  155,  155,  155,  232,  233,  234,  178,  180,   72,
      122,  122,  122,  122,  122,  122,  122,  124,  113,  108,
      173,  173,  173,  173,  173,  173,  173,  109,   71,  216,
      156,  157,  158,  159,  160,  160,  160,  179,  181,   68,
       68,  116,   72,  152,  152,  152,  152,  152,  152,  116,

      188,  113,  117,  117,  117,  117,  117,  118,  118,  119,
      120,  120,  120,  120,  120,  121,  121,  119,  116,  128,
      128,  128,  128,  128,  128,  128,  116,   60,  214,  164,
      164,  164,  164,  164,  165,  166,  119,  164,  164,  164,
      164,  164,  165,  166,  119,  116,  215,   75,   68,   68,
      182,  270,  116,  133,  258,  234,  169,  169,  169,  169,
      169,  165,  166,  170,  170,  170,  170,  170,  171,  172,
      123,  123,  123,  123,  123,  123,  123,  124,  174,  174,
      183,  248,  175,  175,  175,  175,  175,  175,  175,  126,
      126,  126,  126,  126,  126,  126,  240,  241,  242,  249,

      250,  125,  128,  128,  128,  128,  128,  128,  128,  189,
      224,  243,  231,  231,  116,  214,  187,  190,  251,  184,
      152,  152,  152,  212,  265,  169,  169,  169,  169,  169,
      165,  166,  173,  173,  173,  173,  173,  173,  173,  116,
      108,  191,  108,  175,  175,  175,  175,  175,  175,  175,
      109,   71,  103,  192,  193,  194,  194,  194,  194,  194,
      258,  259,  259,  252,   60,   72,  175,  175,  175,  175,
      175,  175,  175,  148,  113,  108,  148,  148,  148,  148,
      148,  253,   59,  109,   71,   75,  195,  196,  197,  198,
      199,  199,  199,   75,   75,   75,   92,   92,   72,   75,

      133,   75,   92,  263,  264,  264,   75,  113,  108,  220,
      221,  221,  222,  223,  223,  223,  109,   71,  214,  203,
      204,  205,  206,  207,  207,  207,   73,  265,   70,  247,
      116,   72,  223,  223,  223,  223,  223,  223,  214,  212,
      113,  213,  170,  170,  170,  170,  171,  172,  116,  168,
      168,  168,  168,  168,  168,  168,  215,  212,  116,  170,
      170,  170,  170,  170,  171,  172,  101,  212,  116,  170,
      170,  170,  170,  170,  171,  172,  116,  212,  100,  172,
      172,  172,  172,  172,  172,  172,  108,  244,  244,  244,
      244,  244,  244,  244,  109,   71,   99,  224,  225,  226,

      226,  226,  226,  226,  270,   98,   75,   68,  231,   72,
      245,  245,  245,  245,  245,  246,  247,   97,  113,  108,
      257,  257,  257,  257,   73,   70,  106,  109,   71,  101,
      227,  228,  229,  230,  231,  231,  231,   75,  189,  185,
      100,  254,   72,  186,  254,  254,  254,  254,  254,  223,
      223,  113,  108,   99,   98,   97,   95,   75,   73,   70,
      109,   71,   66,  235,  236,  237,  238,  239,  239,  239,
      191,  270,  270,  270,  116,   72,  270,  270,  270,  270,
      270,  189,  270,  212,  113,  172,  172,  172,  172,  172,
      172,  172,  223,  223,  223,  223,  223,  223,  223,  270,

       71,  270,   68,  226,  226,  226,  226,  226,  226,  270,
      270,  270,  270,  191,   72,  108,  270,  270,  270,  270,
      270,  270,  270,  270,   71,  270,  255,  234,  234,  256,
      257,  257,  257,  270,  270,  270,  270,   71,   72,   68,
      231,  231,  231,  231,  231,  231,  270,  113,  108,  270,
      270,   72,  270,  270,  270,  270,  270,   71,  270,  260,
      242,  242,  261,  262,  262,  262,  270,  270,  270,  270,
      116,   72,  270,  270,  270,  270,  270,  270,  270,  214,
      113,  244,  244,  244,  244,  244,  244,  244,  265,  270,
      247,  247,  247,  247,  247,  247,  247,  108,  270,  270,

      270,  270,  270,  270,  270,  270,   71,  270,  257,  257,
       68,   68,   68,   68,   68,  270,  270,  270,  270,   71,
       72,   68,  257,  257,  257,  257,  257,  257,  214,  113,
      270,  270,  270,   72,  270,  214,  270,  270,  270,  269,
      269,  269,  269,  269,  269,  269,  269,  269,  269,  269,
      269,  269,  269,   12,   12,   12,   94,   94,  130,  130,
       11,  270,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,

      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270
    } ;

static const flex_int16_t yy_chk[1325] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    3,    3,   26,   26,   27,   27,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,   13,    3,    3,   25,   28,   28,    3,   33,   79,
       25,   13,    3,    3,    3,  274,    3,   33,   79,    3,

       13,   13,   82,   45,   45,   13,   45,   45,   82,  272,
       13,   13,   13,   19,   19,   19,   19,   19,   19,   19,
        3,   57,   57,   57,    3,    4,    4,   57,  112,  112,
      112,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,  268,    4,    4,   46,   46,   90,    4,
       46,  267,   46,   92,    4,    4,    4,   92,    4,   90,
       17,    4,   17,   17,   17,   17,   17,   17,   17,   18,
       30,   18,   18,   18,   18,   18,   18,   18,   97,   94,
       30,   30,    4,   30,   30,   97,    4,    5,   94,  223,
       77,   77,   77,    5,    5,    5,   77,    5,    5,    5,

        5,    5,    5,    5,   21,   76,   21,   21,   21,   21,
       21,   21,   21,   76,   84,   98,  101,   84,   21,   87,
       76,  223,    5,    6,   87,   98,  101,   84,   81,    6,
        6,    6,   81,    6,    6,    6,    6,    6,    6,    6,
       29,   29,   81,   87,   29,   29,   29,   29,   29,   29,
       29,   36,   36,   36,   36,   36,   36,   36,    6,    7,
      129,  129,  102,  103,  266,    7,    7,  102,  103,    7,
        7,    7,    7,    7,    7,    7,   31,   31,   31,   31,
       31,  263,   31,   31,  253,   31,   37,   37,   37,   37,
       37,   37,   37,  104,    7,    8,  132,  131,  104,  131,

      148,    8,    8,  252,  148,    8,    8,    8,    8,    8,
        8,    8,   39,   39,   39,   39,   39,   39,   39,   48,
      132,   48,   48,   48,   48,   48,   48,   48,   88,   89,
        8,    9,  133,   88,   89,  159,  159,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,  130,
        9,    9,   88,   89,  172,    9,  133,  134,  130,  134,
        9,    9,    9,  172,    9,   49,   49,   49,   49,   49,
       49,   49,   51,   51,   51,   51,   51,   51,   51,   55,
       55,   55,   55,   55,   55,   55,  135,  251,    9,  177,
      177,  135,    9,   23,   23,   23,   23,   23,   23,   23,

      198,  198,   23,   23,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   52,   23,   23,   23,   23,
       23,   23,  206,  206,  136,  250,   52,   52,   52,   52,
       52,   52,   52,   52,  138,  249,  143,  248,  144,   23,
       23,   23,   23,   23,   50,   67,   67,   67,   67,   67,
       67,   67,   50,   50,  136,   50,   50,   50,   50,   50,
       50,   50,  214,  137,  138,  139,   53,   50,  137,  143,
      139,  144,  140,  143,   54,  144,   50,   53,   53,   53,
       53,   53,   53,   53,   53,   54,   54,   54,   54,   54,
       54,   54,   54,   56,   56,   56,   56,   56,   56,   56,

       56,   58,  140,  149,  141,  141,  189,  149,   66,   66,
      141,   58,   66,   66,   66,   66,   66,   66,   66,  188,
       58,   58,  155,  155,  155,   58,  152,  158,  158,  158,
       58,   58,   58,   68,  152,   68,   68,   68,   68,   68,
       68,   68,  161,  161,  161,  161,  171,   68,   69,   69,
       69,   69,   69,   69,   69,  171,  187,  171,  152,  186,
       69,   71,   71,   71,   71,   71,   71,   71,  230,  230,
       72,   72,  183,   71,   72,   72,   72,   72,   72,   72,
       72,   85,   85,   85,   85,   85,   85,   85,   86,   86,
       86,   86,   86,   86,   86,   95,   95,   95,   95,   95,

       95,   95,   95,   95,   95,   95,   95,   95,   95,   95,
       95,   95,   96,   96,   96,   96,   96,   96,   96,  106,
      238,  238,  106,  106,  106,  106,  106,  106,  106,  109,
      109,  109,  109,  109,  109,  109,  110,  119,  119,  119,
      119,  119,  119,  119,  110,  110,  181,  110,  110,  110,
      110,  110,  110,  110,  194,  194,  194,  178,  180,  110,
      122,  122,  122,  122,  122,  122,  122,  122,  110,  111,
      124,  124,  124,  124,  124,  124,  124,  111,  111,  179,
      111,  111,  111,  111,  111,  111,  111,  178,  180,  257,
      257,  114,  111,  150,  150,  150,  150,  150,  150,  115,

      147,  111,  114,  114,  114,  114,  114,  114,  114,  114,
      115,  115,  115,  115,  115,  115,  115,  115,  117,  127,
      127,  127,  127,  127,  127,  127,  118,  146,  168,  117,
      117,  117,  117,  117,  117,  117,  117,  118,  118,  118,
      118,  118,  118,  118,  118,  120,  168,  176,  262,  262,
      182,  227,  121,  176,  227,  227,  120,  120,  120,  120,
      120,  120,  120,  121,  121,  121,  121,  121,  121,  121,
      123,  123,  123,  123,  123,  123,  123,  123,  125,  125,
      182,  216,  125,  125,  125,  125,  125,  125,  125,  126,
      126,  126,  126,  126,  126,  126,  197,  197,  197,  216,

      217,  126,  128,  128,  128,  128,  128,  128,  128,  151,
      200,  200,  200,  200,  164,  247,  145,  151,  217,  142,
      151,  151,  151,  164,  247,  164,  164,  164,  164,  164,
      164,  164,  173,  173,  173,  173,  173,  173,  173,  116,
      108,  151,  153,  174,  174,  174,  174,  174,  174,  174,
      153,  153,  105,  153,  153,  153,  153,  153,  153,  153,
      226,  226,  226,  218,  100,  153,  175,  175,  175,  175,
      175,  175,  175,  184,  153,  154,  184,  184,  184,  184,
      184,  218,   99,  154,  154,   91,  154,  154,  154,  154,
      154,  154,  154,  185,  185,  185,  185,  185,  154,  185,

       83,   75,  185,  229,  229,  229,   74,  154,  157,  190,
      190,  190,  190,  190,  190,  190,  157,  157,  246,  157,
      157,  157,  157,  157,  157,  157,   73,  246,   70,  246,
      165,  157,  220,  220,  220,  220,  220,  220,  167,  165,
      157,  165,  165,  165,  165,  165,  165,  165,  166,  167,
      167,  167,  167,  167,  167,  167,  167,  166,  169,  166,
      166,  166,  166,  166,  166,  166,   65,  169,  170,  169,
      169,  169,  169,  169,  169,  169,  212,  170,   64,  170,
      170,  170,  170,  170,  170,  170,  192,  212,  212,  212,
      212,  212,  212,  212,  192,  192,   63,  192,  192,  192,

      192,  192,  192,  192,  240,   62,  254,  240,  240,  192,
      215,  215,  215,  215,  215,  215,  215,   61,  192,  193,
      259,  259,  259,  259,   60,   59,   47,  193,  193,   44,
      193,  193,  193,  193,  193,  193,  193,  219,  222,  254,
       43,  219,  193,  254,  219,  219,  219,  219,  219,  222,
      222,  193,  196,   42,   41,   40,   35,   24,   22,   20,
      196,  196,   16,  196,  196,  196,  196,  196,  196,  196,
      222,   11,    0,    0,  213,  196,    0,    0,    0,    0,
        0,  221,    0,  213,  196,  213,  213,  213,  213,  213,
      213,  213,  221,  221,  221,  221,  221,  221,  221,    0,

      224,    0,  224,  224,  224,  224,  224,  224,  224,    0,
        0,    0,    0,  221,  224,  225,    0,    0,    0,    0,
        0,    0,    0,    0,  225,    0,  225,  225,  225,  225,
      225,  225,  225,    0,    0,    0,    0,  232,  225,  232,
      232,  232,  232,  232,  232,  232,    0,  225,  228,    0,
        0,  232,    0,    0,    0,    0,    0,  228,    0,  228,
      228,  228,  228,  228,  228,  228,    0,    0,    0,    0,
      244,  228,    0,    0,    0,    0,    0,    0,    0,  245,
      228,  244,  244,  244,  244,  244,  244,  244,  245,    0,
      245,  245,  245,  245,  245,  245,  245,  256,    0,    0,

        0,    0,    0,    0,    0,    0,  256,    0,  256,  256,
      256,  256,  256,  256,  256,    0,    0,    0,    0,  258,
      256,  258,  258,  258,  258,  258,  258,  258,  265,  256,
        0,    0,    0,  258,    0,  269,    0,    0,    0,  265,
      265,  265,  265,  265,  265,  265,  269,  269,  269,  269,
      269,  269,  269,  271,  271,  271,  273,  273,  275,  275,
      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,

      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "../harp/udunits2/utscanner.l"
/*
 * Copyright 2014 University Corporation for Atmospheric Research
 *
 * This file is part of the UDUNITS-2 package.  See the file COPYRIGHT
 * in the top-level source-directory of the package for copying and
 * redistribution conditions.
 */
/*
 * lex(1) specification for tokens for the Unidata units package, UDUNITS2.
 */
#define YY_NO_INPUT 1
#line 18 "../harp/udunits2/utscanner.l"

/* This define is to allow more than one yacc file in the program */
#define yylval utlval

#include <ctype.h>
#include <errno.h>
#include <limits.h>
#define _USE_MATH_DEFINES
#include <math.h>
#include <stddef.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>

#include "udunits2.h"
#include "utparser.h"

int utrestartScanner = 0;
int utisTime = 0;

int ut_get_bufferpos(YY_BUFFER_STATE buf)
{
    return yy_c_buf_p - buf->yy_ch_buf;
}

/**
 * Decodes a date.
 *
 * @param[in]  text     The text specifying the date to be decoded.
 * @param[in]  format   The format to use for decoding. The order is year (int),
 *                      month (int), and day (int).
 * @param[out] date     The date corresponding to the input.
 * @retval     DATE     Success
 * @retval     ERR      Error
 */
static int decodeDate(
    const char* const   text,
    const char* const   format,
    double* const       date)
{
    int		year;
    int		month = 1;
    int		day = 1;

    (void)sscanf(text, format, &year, &month, &day);
    *date = ut_encode_date(year, month, day);
    return DATE;
}

/**
 * Decodes a clock-time.
 *
 * @param[in] text      The text specifying the clock-time to be decoded.
 * @param[in] format    The format to use for decoding. The order is hour (int),
 *                      minute (int), and second (double).
 * @return              The clock-time corresponding to the input.
 */
static double decodeClock(
    const char* const   text,
    const char* const   format)
{
    int         hour = 0;
    int         minute = 0;
    double      second = 0;

    (void)sscanf(text, format, &hour, &minute, &second);
    if (hour < 0) {
        minute = -minute;
        second = -second;
    }
    return ut_encode_clock(hour, minute, second);
}

/**
 * Decodes a real value.
 *
 * @param[in]  text     Text to be decoded.
 * @param[out] value    Decoded value.
 * @retval     REAL     Success.
 * @retval     ERR      Failure.
 */
static int decodeReal(
    const char* const text,
    double* const     value)
{
    errno = 0;
    *value = strtod(text, NULL);

    if (errno == 0)
        return REAL;

    ut_handle_error_message("Invalid real: \"%s\"", text);
    return ERR;
}

#line 1194 "udunits2/utscanner.c"

#line 1196 "udunits2/utscanner.c"

#define INITIAL 0
#define ID_SEEN 1
#define SHIFT_SEEN 2
#define DATE_SEEN 3
#define CLOCK_SEEN 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 164 "../harp/udunits2/utscanner.l"

#line 166 "../harp/udunits2/utscanner.l"
    if (utrestartScanner) {
	BEGIN INITIAL;
	utrestartScanner = 0;
    }

#line 1423 "udunits2/utscanner.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 271 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1261 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 171 "../harp/udunits2/utscanner.l"
{
    BEGIN SHIFT_SEEN;
    return SHIFT;
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 176 "../harp/udunits2/utscanner.l"
{
    BEGIN INITIAL;
    return DIVIDE;
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 181 "../harp/udunits2/utscanner.l"
{
    BEGIN INITIAL;
    return MULTIPLY;
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 186 "../harp/udunits2/utscanner.l"
{
    int		status;

    if (sscanf(yytext, "%*[*^]%ld", &yylval.ival) != 1) {
        ut_handle_error_message("Invalid integer\n", stderr);

	status	= ERR;
    }
    else {
	status	= EXPONENT;
    }

    return status;
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 201 "../harp/udunits2/utscanner.l"
{
    int		status = EXPONENT;
    int		exponent = 0;
    int		sign = 1;
    char*	cp = yytext;

    if (strncmp(cp, "\xe2\x81\xba", 3) == 0) {
	cp += 3;
    }
    else if (strncmp(cp, "\xe2\x81\xbb", 3) == 0) {
	sign = -1;
	cp += 3;
    }

    while (cp < yytext + yyleng) {
	int	j;
	static struct {
	    const char*	string;
	    const int	len;
	} utf8_exponents[] = {
	    {"\xe2\x81\xb0", 3},        /* 0 */
	    {"\xc2\xb9",     2},        /* 1 */
	    {"\xc2\xb2",     2},        /* 2 */
	    {"\xc2\xb3",     2},        /* 3 */
	    {"\xe2\x81\xb4", 3},        /* 4 */
	    {"\xe2\x81\xb5", 3},        /* 5 */
	    {"\xe2\x81\xb6", 3},        /* 6 */
	    {"\xe2\x81\xb7", 3},        /* 7 */
	    {"\xe2\x81\xb8", 3},        /* 8 */
	    {"\xe2\x81\xb9", 3},        /* 9 */
	};

        if (exponent > INT_MAX/10) {
            status = ERR;
            break;
        }

	exponent *= 10;

	for (j = 0; j < 10; j++) {
	    int	len = utf8_exponents[j].len;

	    if (strncmp(cp, utf8_exponents[j].string, len) == 0) {
		exponent += j;
		cp += len;
		break;
	    }
	}

	if (j >= 10) {
	    status = ERR;
	    break;
	}
    }

    if (status == EXPONENT)
	yylval.ival = sign * exponent;

    BEGIN INITIAL;
    return status;
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 263 "../harp/udunits2/utscanner.l"
{
    BEGIN DATE_SEEN;
    return decodeDate((char*)yytext, "%d-%d-%d", &yylval.rval);
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 268 "../harp/udunits2/utscanner.l"
{
    if (utisTime) {
        BEGIN DATE_SEEN;
        return decodeDate((char*)yytext, "%4d%2d%2d", &yylval.rval);
    }
    else {
        BEGIN INITIAL;
        return decodeReal((char*)yytext, &yylval.rval);
    }
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 279 "../harp/udunits2/utscanner.l"
{
    yylval.rval = decodeClock((char*)yytext, "%d:%d:%lf");
    BEGIN CLOCK_SEEN;
    return CLOCK;
}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 285 "../harp/udunits2/utscanner.l"
{
    yylval.rval = decodeClock((char*)yytext, "%2d%2d%lf");
    BEGIN CLOCK_SEEN;
    return CLOCK;
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 291 "../harp/udunits2/utscanner.l"
{
    yylval.rval	= decodeClock((char*)yytext, "%d:%d");
    BEGIN INITIAL;
    return CLOCK;
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 297 "../harp/udunits2/utscanner.l"
{
    yylval.rval	= (yyleng <= 3)
                        ? decodeClock((char*)yytext, "%d")
                        : (yyleng == 4)
                            ? decodeClock((char*)yytext, "%2d%d")
                            : decodeClock((char*)yytext, "%3d%d");
    BEGIN INITIAL;
    return CLOCK;
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 307 "../harp/udunits2/utscanner.l"
{
    yylval.rval	= (yyleng <= 2)
                        ? decodeClock((char*)yytext, "%d")
                        : (yyleng == 3)
                            ? decodeClock((char*)yytext, "%1d%d")
                            : decodeClock((char*)yytext, "%2d%d");
    BEGIN INITIAL;
    return CLOCK;
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 317 "../harp/udunits2/utscanner.l"
{
    BEGIN INITIAL;
    return decodeReal((char*)yytext, &yylval.rval);
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 322 "../harp/udunits2/utscanner.l"
{
    int		status;

    errno	= 0;
    yylval.ival = atol((char*)yytext);

    if (errno == 0) {
	status	= INT;
    } else {
        ut_handle_error_message("Invalid integer\n", stderr);

	status	= ERR;
    }

    BEGIN INITIAL;
    return status;
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 340 "../harp/udunits2/utscanner.l"
{
    yylval.rval = 10;
    return LOGREF;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 345 "../harp/udunits2/utscanner.l"
{
    yylval.rval = M_E;
    return LOGREF;
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 350 "../harp/udunits2/utscanner.l"
{
    yylval.rval = 2;
    return LOGREF;
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 355 "../harp/udunits2/utscanner.l"
{
    yylval.id = strdup((char*)yytext);

    BEGIN ID_SEEN;
    return ID;
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 362 "../harp/udunits2/utscanner.l"
{
    BEGIN INITIAL;
    return yytext[0];
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 367 "../harp/udunits2/utscanner.l"
ECHO;
	YY_BREAK
#line 1738 "udunits2/utscanner.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(ID_SEEN):
case YY_STATE_EOF(SHIFT_SEEN):
case YY_STATE_EOF(DATE_SEEN):
case YY_STATE_EOF(CLOCK_SEEN):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 271 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 271 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 270);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 367 "../harp/udunits2/utscanner.l"


